==> haskell-bytestring-tree-builder-0.2.7.9-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-tree-builder
version:              0.2.7.9
visibility:           public
id:                   bytestring-tree-builder-0.2.7.9-5GEZ2MnaT80IeFtF2tTPnN
key:                  bytestring-tree-builder-0.2.7.9-5GEZ2MnaT80IeFtF2tTPnN
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/bytestring-tree-builder
synopsis:
    A very efficient ByteString builder implementation based on the binary tree

description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.

category:             ByteString
abi:                  071ab4f042d3131d6400a5d7c2cf179c
exposed:              True
exposed-modules:      ByteString.TreeBuilder
hidden-modules:
    ByteString.TreeBuilder.Prelude ByteString.TreeBuilder.Poker
    ByteString.TreeBuilder.Tree

import-dirs:
    /usr/lib/ghc-9.0.2/site-local/bytestring-tree-builder-0.2.7.9

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/bytestring-tree-builder-0.2.7.9

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-tree-builder
hs-libraries:         HSbytestring-tree-builder-0.2.7.9-5GEZ2MnaT80IeFtF2tTPnN
depends:              base-4.15.1.0 bytestring-0.10.12.1 text-1.2.5.0
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-tree-builder-0.2.7.9-98-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-tree-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-tree-builder
version:              0.2.7.9
visibility:           public
id:                   bytestring-tree-builder-0.2.7.9-9XIts2MTBwFiELsLRiE0c
key:                  bytestring-tree-builder-0.2.7.9-9XIts2MTBwFiELsLRiE0c
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/bytestring-tree-builder
synopsis:
    A very efficient ByteString builder implementation based on the binary tree

description:
    According to
    <https://github.com/nikita-volkov/bytestring-builders-benchmark the benchmarks>
    this builder implementation beats all the alternatives.
    It is especially well-suited for generating strict bytestrings,
    beating the standard builder by at least the factor of 4.

category:             ByteString
abi:                  ab028b3e42e49b071034ba11ed182189
exposed:              True
exposed-modules:      ByteString.TreeBuilder
hidden-modules:
    ByteString.TreeBuilder.Prelude ByteString.TreeBuilder.Poker
    ByteString.TreeBuilder.Tree

import-dirs:
    /usr/lib/ghc-9.0.2/site-local/bytestring-tree-builder-0.2.7.9

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/bytestring-tree-builder-0.2.7.9

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-tree-builder
hs-libraries:         HSbytestring-tree-builder-0.2.7.9-9XIts2MTBwFiELsLRiE0c
depends:              base-4.15.1.0 bytestring-0.10.12.1 text-1.2.5.0
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-tree-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
